#! /bin/bash -eu
#! -*- coding:utf-8; mode:shell-script; -*-


set -eu
shopt -s nullglob

texout="${texout:-/dev/null}"
texerr="${texerr:-/dev/stderr}"

function fail {
    echo "run-latex.sh: error: $@" >&2
    exit 1
}

function cleanup {
    [ ! -f aux.md5 ] || rm -f aux.md5
}

[ $# -eq 1 ] || fail "Wrong number of arguments"
[ "x${TEX+set}" = xset ] || fail "Environment variable TEX is not set"
[ "x${TEXFLAGS+set}" = xset ] || fail "Environment variable TEXFLAGS is not set"
[ -f "$1" ] || fail "$1: File does not exitst"

directory="$(dirname "$1")"
filename="$(basename "$1")"
jobname="${filename%.tex}"

cd "./${directory}/"

[ "x${SOURCE_DATE_EPOCH+set}" = xset ]                                        \
    || export SOURCE_DATE_EPOCH="$$(date --reference="${filename}" +'%s')"

trap cleanup EXIT

touch "${jobname}.aux"
i=0

while :
do
    i=$((${i} + 1))
    md5sum *.aux </dev/null >aux.md5
    printf '%6s %s\n' 'TEX' "$1"
    ${TEX} ${TEXFLAGS} "${filename}" 1>"${texout}" 2>"${texerr}"
    if md5sum --check aux.md5 1>/dev/null 2>/dev/null; then break; fi
    if [ ${i} -gt 10 ]; then fail "TeX did not converge"; fi
done
rm -f aux.md5
