final class AudioPlayer {

    private interface State {
        State pressStop();
        State pressPlayPause();
    };

    private final class StateStopped implements State {

        @Override
        public State pressStop() {
            System.out.println("There is nothing to stop");
            return this;
        }

        @Override
        public State pressPlayPause() {
            System.out.println("Playing from the beginning...");
            return new StatePlaying();
        }

    };

    private final class StatePaused implements State {

        private final long savedTrack;
        private final long savedPosition;

        public StatePaused(final long track, final long position) {
            this.savedTrack = track;
            this.savedPosition = position;
        }

        @Override
        public State pressStop() {
            System.out.println("Clearing saved track and position");
            return new StateStopped();
        }

        @Override
        public State pressPlayPause() {
            System.out.printf("Continuing playing track %d from position %d ...%n",
                              this.savedTrack, this.savedPosition);
            return new StatePlaying();
        }

    };

    private final class StatePlaying implements State {

        @Override
        public State pressStop() {
            System.out.println("Stopping playing music");
            return new StateStopped();
        }

        @Override
        public State pressPlayPause() {
            final long track = AudioPlayer.this.getCurrentTrack();
            final long position = AudioPlayer.this.getCurrentPosition();
            System.out.printf("Pausing track %d at position %d%n", track, position);
            return new StatePaused(track, position);
        }

    };

    private State state;

    public AudioPlayer() {
        this.state = new StateStopped();
    }

    public void pressStop() {
        this.state = this.state.pressStop();
    }

    public void pressPlayPause() {
        this.state = this.state.pressPlayPause();
    }

    private long getCurrentTrack() {
        return (17 * System.nanoTime()) % 12;
    }

    private long getCurrentPosition() {
        return System.nanoTime() % 100;
    }

    public static void main(final String[] args) {
        final AudioPlayer player = new AudioPlayer();
        for (final String cmd : args) {
            switch (cmd) {
            case "S":
                System.out.printf("%-16s", "Stop:");
                player.pressStop();
                break;
            case "P":
                System.out.printf("%-16s", "Play/Pause:");
                player.pressPlayPause();
                break;
            default:
                System.err.printf("There is no '%s' button%n!", cmd);
            }
        }
    }

}
