final class AudioPlayer {

    private static enum States { STOPPED, PAUSED, PLAYING };

    private States state;

    private long savedTrack;
    private long savedPosition;

    public AudioPlayer() {
        this.state = States.STOPPED;
    }

    public void pressStop() {
        switch (this.state) {
        case STOPPED:
            System.out.println("There is nothing to stop");
            break;
        case PAUSED:
            System.out.println("Clearing saved track and position");
            this.savedTrack = 0;
            this.savedPosition = 0;
            this.state = States.STOPPED;
            break;
        case PLAYING:
            System.out.println("Stopping playing music");
            this.state = States.STOPPED;
            break;
        default:
            throw new AssertionError();
        }
    }

    public void pressPlayPause() {
        switch (this.state) {
        case STOPPED:
            System.out.println("Playing from the beginning...");
            this.state = States.PLAYING;
            break;
        case PAUSED:
            System.out.printf("Continuing playing track %d from position %d...%n",
                              this.savedTrack, this.savedPosition);
            this.savedTrack = 0;
            this.savedPosition = 0;
            this.state = States.PLAYING;
            break;
        case PLAYING:
            this.savedTrack = this.getCurrentTrack();
            this.savedPosition = this.getCurrentPosition();
            System.out.printf("Pausing track %d at position %d%n",
                              this.savedTrack, this.savedPosition);
            this.state = States.PAUSED;
            break;
        default:
            throw new AssertionError();
        }
    }

    private long getCurrentTrack() {
        return (17 * System.nanoTime()) % 12;
    }

    private long getCurrentPosition() {
        return System.nanoTime() % 100;
    }

    public static void main(final String[] args) {
        final AudioPlayer player = new AudioPlayer();
        for (final String cmd : args) {
            switch (cmd) {
            case "S":
                System.out.printf("%-16s", "Stop:");
                player.pressStop();
                break;
            case "P":
                System.out.printf("%-16s", "Play/Pause:");
                player.pressPlayPause();
                break;
            default:
                System.err.printf("There is no '%s' button%n!", cmd);
            }
        }
    }

}
