final class AudioPlayer {

    private static final int STATE_STOPPED      = 0;
    private static final int STATE_PAUSED       = 1;
    private static final int STATE_PLAYING      = 2;

    private static final int BUTTON_STOP        = 0;
    private static final int BUTTON_PLAY_PAUSE  = 1;

    private static final int[][] TRANSITIONS = {
        //               stop           play/pause
        /* stopped */  { STATE_STOPPED, STATE_PLAYING },
        /* paused  */  { STATE_STOPPED, STATE_PLAYING },
        /* playing */  { STATE_STOPPED, STATE_PAUSED  },
    };

    private int state;

    private long savedTrack;
    private long savedPosition;

    public AudioPlayer() {
        this.state = STATE_STOPPED;
    }

    public void pressStop() {
        final String[] messages = {
            "Stopping playing music",
            "Clearing saved track and position.",
            "There is nothing to stop",
        };
        System.out.println(messages[this.state]);
        this.state = TRANSITIONS[this.state][BUTTON_STOP];
    }

    public void pressPlayPause() {
        this.state = TRANSITIONS[this.state][BUTTON_PLAY_PAUSE];
        if (this.state == STATE_PLAYING) {
            if ((this.savedTrack == 0) && (this.savedPosition == 0)) {
                System.out.println("Playing from the beginning...");
            } else {
                System.out.printf("Continuing playing track %d from position %d ...%n",
                                  this.savedTrack, this.savedPosition);
            }
        } else {
            this.savedTrack = this.getCurrentTrack();
            this.savedPosition = this.getCurrentPosition();
            System.out.printf("Pausing track %d at position %d%n",
                              this.savedTrack, this.savedPosition);
        }
    }

    private long getCurrentTrack() {
        return (17 * System.nanoTime()) % 12;
    }

    private long getCurrentPosition() {
        return System.nanoTime() % 100;
    }

    public static void main(final String[] args) {
        final AudioPlayer player = new AudioPlayer();
        for (final String cmd : args) {
            switch (cmd) {
            case "S":
                System.out.printf("%-16s", "Stop:");
                player.pressStop();
                break;
            case "P":
                System.out.printf("%-16s", "Play/Pause:");
                player.pressPlayPause();
                break;
            default:
                System.err.printf("There is no '%s' button%n!", cmd);
            }
        }
    }

}
